@@ -1,11 +1,13 @@
 # -*- coding: utf-8 -*-
 """internet layer protocols
 
-``jspcap.protocols.internet`` is collection of all
-protocols in internet layer, with detailed implementation
-and methods.
+`jspcap.protocols.internet` is collection of all protocols
+in internet layer, with detailed implementation and
+methods.
 
 """
+# TODO: Implements ECN, ESP, ICMP, ICMPv6, IGMP, Shim6.
+
 # Base Class for Internet Layer
 from jspcap.protocols.internet.internet import Internet
 
@@ -32,7 +34,8 @@ from jspcap.protocols.internet.ipsec import IPsec
 
 
 __all__ = [
-    'ETHERTYPE',                                                    # Protocol Numbers
-    'AH', 'IP', 'IPX',                                              # Internet Layer Protocols
-    'HIP', 'HOPOPT', 'IPv6_Frag', 'IPv6_Opts', 'IPv6_Route', 'MH',  # IPv6 Extension Headers
+    'ETHERTYPE',                                        # Protocol Numbers
+    'AH', 'IP', 'IPsec', 'IPv4', 'IPv6', 'IPX',         # Internet Layer
+    'HIP', 'HOPOPT', 'IPv6_Frag',
+    'IPv6_Opts', 'IPv6_Route', 'MH',                    # IPv6 Extension Header
 ]
