@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """host identity protocol
 
-``jspcap.protocols.internet.hip`` contains ``HIP``
+`jspcap.protocols.internet.hip` contains `HIP`
 only, which implements extractor for Host Identity
 Protocol (HIP), whose structure is described as below.
 
@@ -30,15 +30,9 @@ Protocol (HIP), whose structure is described as below.
 
 """
 # TODO: Implements extractor of all HIP parameters.
-
-
-# Host Identity Protocol
-# Analyser for HIP header
-
-
-from jspcap.exceptions import ProtocolError
-from jspcap.utilities import Info
+from jspcap.corekit.infoclass import Info
 from jspcap.protocols.protocol import Protocol
+from jspcap.utilities.exceptions import ProtocolError
 
 
 __all__ = ['HIP']
@@ -145,19 +139,19 @@ class HIP(Protocol):
             |                                                               |
             +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 
-            Octets          Bits          Name                Discription
-              0              0          hip.next          Next Header
-              1              8          hip.length        Header Length
-              2              16         -                 Reserved (0)
-              2              17         hip.type          Packet Type
-              3              24         hip.version       Version
-              3              28         -                 Reserved
-              3              31         -                 Reserved (1)
-              4              32         hip.chksum        Checksum
-              6              48         hip.control       Controls
-              8              64         hip.shit          Sender's Host Identity Tag
-              24             192        hip.rhit          Receiver's Host Identity Tag
-              40             320        hip.parameters    HIP Parameters
+            Octets      Bits        Name                    Discription
+              0           0     hip.next                Next Header
+              1           8     hip.length              Header Length
+              2          16     -                       Reserved (0)
+              2          17     hip.type                Packet Type
+              3          24     hip.version             Version
+              3          28     -                       Reserved
+              3          31     -                       Reserved (1)
+              4          32     hip.chksum              Checksum
+              6          48     hip.control             Controls
+              8          64     hip.shit                Sender's Host Identity Tag
+              24        192     hip.rhit                Receiver's Host Identity Tag
+              40        320     hip.parameters          HIP Parameters
 
         """
         if length is None:
