@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """IPv6 hop-by-hop options
 
-``jspcap.protocols.internet.hopopt`` contains ``HOPOPT``
+`jspcap.protocols.internet.hopopt` contains `HOPOPT`
 only, which implements extractor for IPv6 Hop-by-Hop
 Options header (HOPOPT), whose structure is described
 as below.
@@ -18,13 +18,7 @@ as below.
 
 """
 # TODO: Implements extractor of all hop-by-hop options.
-
-
-# IPv6 Hop-by-Hop Option
-# Analyser for HOPOPT header
-
-
-from jspcap.utilities import Info
+from jspcap.corekit.infoclass import Info
 from jspcap.protocols.protocol import Protocol
 
 
@@ -98,10 +92,10 @@ class HOPOPT(Protocol):
             |                                                               |
             +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 
-            Octets          Bits          Name                Discription
-              0              0          hopopt.next       Next Header
-              1              8          hopopt.length     Header Extensive Length
-              2              16         hopopt.options    Options
+            Octets      Bits        Name                    Discription
+              0           0     hopopt.next             Next Header
+              1           8     hopopt.length           Header Extensive Length
+              2          16     hopopt.options          Options
 
         """
         if length is None:
