@@ -1,47 +1,24 @@
 # -*- coding: utf-8 -*-
 """root internet layer protocol
 
-``jspcap.protocols.internet.internet`` contains both
-``ETHERTYPE`` and ``Internet``. The former is a dictionary
+`jspcap.protocols.internet.internet` contains both
+`ETHERTYPE` and `Internet`. The former is a dictionary
 of ethertype IEEE 802 numbers, registered in IANA. And the
 latter is a base class for internet layer protocols, eg.
 AH, IP, IPsec, IPv4, IPv6, IPX, and etc.
 
 """
-# TODO: Implements ECN, ESP, ICMP, ICMPv6, IGMP, Shim6.
-
-
 import io
 
-
-# Internet Layer Protocols
-# Table of corresponding protocols
-
-
-from jspcap.utilities import beholder, ProtoChain
+from jspcap.corekit.protochain import ProtoChain
 from jspcap.protocols.protocol import Protocol
 from jspcap.protocols.transport.transport import TP_PROTO
+from jspcap.utilities.decorators import beholder
 
 
 __all__ = ['Internet', 'ETHERTYPE']
 
 
-# ##############################################################################
-# # for unknown reason and never-encountered situation, at current time
-# # we have to change the working directory to import from parent folders
-#
-# import os
-# import sys
-# sys.path.insert(1, os.path.join(sys.path[0], '..'))
-#
-# from protocol import Protocol
-#
-# del sys.path[1]
-#
-# # and afterwards, we recover the whole scene back to its original state
-# ##############################################################################
-
-
 # Ethertype IEEE 802 Numbers
 ETHERTYPE = {
     # Link Layer
@@ -102,8 +79,11 @@ class Internet(Protocol):
     def _read_protos(self, size):
         """Read next layer protocol type.
 
-        Keyword arguments:
-            size  -- int, buffer size
+        Positional arguments:
+            * size  -- int, buffer size
+
+        Returns:
+            * str -- next layer's protocol name
 
         """
         _byte = self._read_unpack(size)
@@ -113,15 +93,23 @@ class Internet(Protocol):
     def _decode_next_layer(self, dict_, proto=None, length=None, *, version=4):
         """Decode next layer extractor.
 
-        Keyword arguments:
-            dict_ -- dict, info buffer
-            proto -- str, next layer protocol name
-            length -- int, valid (not padding) length
-            version -- int, IP version
-                        <4 / 6>
+        Positional arguments:
+            * dict_ -- dict, info buffer
+            * proto -- str, next layer protocol name
+            * length -- int, valid (not padding) length
+
+        Keyword Arguments:
+            * version -- int, IP version (4 in default)
+                            <keyword> 4 / 6
+
+        Returns:
+            * dict -- current protocol with next layer extracted
 
         """
-        flag, info, chain, alias = self._import_next_layer(proto, length, version=version)
+        if self._onerror:
+            flag, info, chain, alias = beholder(self._import_next_layer)(self, proto, length, version=version)
+        else:
+            flag, info, chain, alias = self._import_next_layer(proto, length, version=version)
 
         # make next layer protocol name
         if flag:
@@ -138,15 +126,24 @@ class Internet(Protocol):
         self._protos = ProtoChain(proto, chain, alias)
         return dict_
 
-    @beholder
     def _import_next_layer(self, proto, length=None, *, version=4, extension=False):
         """Import next layer extractor.
 
-        Keyword arguments:
-            proto -- str, next layer protocol name
-            length -- int, valid (not padding) length
-            version -- int, IP version (4/6)
-            extension -- bool, if is extension header (default is False)
+        Positional arguments:
+            * proto -- str, next layer protocol name
+            * length -- int, valid (not padding) length
+
+        Keyword Arguments:
+            * version -- int, IP version (4 in default)
+                            <keyword> 4 / 6
+            * extension -- bool, if is extension header (False in default)
+                            <keyword> True / False
+
+        Returns:
+            * bool -- flag if extraction of next layer succeeded
+            * Info -- info of next layer
+            * ProtoChain -- protocol chain of next layer
+            * str -- alias of next layer
 
         Protocols:
             * IPv4 -- internet layer
@@ -156,7 +153,9 @@ class Internet(Protocol):
             * UDP -- transport layer
 
         """
-        if proto == 'AH':
+        if self._sigterm:
+            from jspcap.protocols.raw import Raw as Protocol
+        elif proto == 'AH':
             from jspcap.protocols.internet.ah import AH as Protocol
         elif proto == 'HIP':
             from jspcap.protocols.internet.hip import HIP as Protocol
@@ -180,5 +179,7 @@ class Internet(Protocol):
             from jspcap.protocols.transport.udp import UDP as Protocol
         else:
             from jspcap.protocols.raw import Raw as Protocol
-        next_ = Protocol(io.BytesIO(self._read_fileng(length)), length, version=version, extension=extension)
+        next_ = Protocol(io.BytesIO(self._read_fileng(length)), length,
+                            version=version, extension=extension,
+                            error=self._onerror, layer=self._exlayer, protocol=self._exproto)
         return True, next_.info, next_.protochain, next_.alias
