@@ -1,46 +1,41 @@
 # -*- coding: utf-8 -*-
 """internet protocol version 6
 
-``jspcap.protocols.internet.ipv6`` contains ``IPv6`` only,
+`jspcap.protocols.internet.ipv6` contains `IPv6` only,
 which implements extractor for Internet Protocol version 6
 (IPv6), whose structure is described as below.
 
-     0                   1                   2                   3
-     0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1
-    +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
-    |Version| Traffic Class |           Flow Label                  |
-    +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
-    |         Payload Length        |  Next Header  |   Hop Limit   |
-    +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
-    |                                                               |
-    +                                                               +
-    |                                                               |
-    +                         Source Address                        +
-    |                                                               |
-    +                                                               +
-    |                                                               |
-    +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
-    |                                                               |
-    +                                                               +
-    |                                                               |
-    +                      Destination Address                      +
-    |                                                               |
-    +                                                               +
-    |                                                               |
-    +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
+ 0                   1                   2                   3
+ 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1
++-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
+|Version| Traffic Class |           Flow Label                  |
++-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
+|         Payload Length        |  Next Header  |   Hop Limit   |
++-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
+|                                                               |
++                                                               +
+|                                                               |
++                         Source Address                        +
+|                                                               |
++                                                               +
+|                                                               |
++-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
+|                                                               |
++                                                               +
+|                                                               |
++                      Destination Address                      +
+|                                                               |
++                                                               +
+|                                                               |
++-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 
 """
 # TODO: Implements IPv6 extension headers.
-
-
 import collections
+import ipaddress
 
-
-# Internet Protocol version 6
-# Analyser for IPv6 header
-
-
-from jspcap.utilities import Info, ProtoChain
+from jspcap.corekit.infoclass import Info
+from jspcap.corekit.protochain import ProtoChain
 from jspcap.protocols.internet.ip import IP
 
 
@@ -61,6 +56,7 @@ EXT_HDR = (
     'Shim6',        # Site Multihoming by IPv6 Intermediation
 )
 
+
 class IPv6(IP):
     """This class implements Internet Protocol version 6.
 
@@ -123,39 +119,39 @@ class IPv6(IP):
 
         Structure of IPv6 header [RFC 2460]:
 
-            0                   1                   2                   3
-            0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1
-           +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
-           |Version| Traffic Class |           Flow Label                  |
-           +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
-           |         Payload Length        |  Next Header  |   Hop Limit   |
-           +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
-           |                                                               |
-           +                                                               +
-           |                                                               |
-           +                         Source Address                        +
-           |                                                               |
-           +                                                               +
-           |                                                               |
-           +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
-           |                                                               |
-           +                                                               +
-           |                                                               |
-           +                      Destination Address                      +
-           |                                                               |
-           +                                                               +
-           |                                                               |
-           +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
+             0                   1                   2                   3
+             0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1
+            +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
+            |Version| Traffic Class |           Flow Label                  |
+            +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
+            |         Payload Length        |  Next Header  |   Hop Limit   |
+            +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
+            |                                                               |
+            +                                                               +
+            |                                                               |
+            +                         Source Address                        +
+            |                                                               |
+            +                                                               +
+            |                                                               |
+            +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
+            |                                                               |
+            +                                                               +
+            |                                                               |
+            +                      Destination Address                      +
+            |                                                               |
+            +                                                               +
+            |                                                               |
+            +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 
-            Octets          Bits          Name                Discription
-              0              0          ip.version        Version (6)
-              0              4          ip.class          Traffic Class
-              1              12         ip.label          Flow Label
-              4              32         ip.payload        Payload Length (header excludes)
-              6              48         ip.next           Next Header
-              7              56         ip.limit          Hop Limit
-              8              64         ip.src            Source Address
-              24             192        ip.dst            Destination Address
+            Octets      Bits        Name                    Discription
+              0           0     ip.version              Version (6)
+              0           4     ip.class                Traffic Class
+              1          12     ip.label                Flow Label
+              4          32     ip.payload              Payload Length (header excludes)
+              6          48     ip.next                 Next Header
+              7          56     ip.limit                Hop Limit
+              8          64     ip.src                  Source Address
+              24        192     ip.dst                  Destination Address
 
         """
         if length is None:
@@ -215,51 +211,55 @@ class IPv6(IP):
 
     def _read_ip_addr(self):
         """Read IP address."""
-        adlt = []       # list of IPv6 hexadecimal address
-        ctr_ = collections.defaultdict(int)
-                        # counter for consecutive groups of zero value
-        ptr_ = 0        # start pointer of consecutive groups of zero value
-        last = False    # if last hextet/group is zero value
-        ommt = False    # ommitted flag, since IPv6 address can ommit to `::` only once
+        # adlt = []       # list of IPv6 hexadecimal address
+        # ctr_ = collections.defaultdict(int)
+        #                 # counter for consecutive groups of zero value
+        # ptr_ = 0        # start pointer of consecutive groups of zero value
+        # last = False    # if last hextet/group is zero value
+        # ommt = False    # ommitted flag, since IPv6 address can ommit to `::` only once
 
-        for _ in range(8):
-            hex_ = self._read_fileng(2).hex().lstrip('0')
+        # for _ in range(8):
+        #     hex_ = self._read_fileng(2).hex().lstrip('0')
 
-            if hex_:    # if hextet is not '', directly append
-                adlt.append(hex_)
-                last = False
-            else:       # if hextet is '', append '0'
-                adlt.append('0')
-                if last:    # if last hextet is '', ascend counter
-                    ctr_[ptr_] += 1
-                else:       # if last hextet is not '', record pointer
-                    ptr_ = _
-                    last = True
-                    ctr_[ptr_] = 1
+        #     if hex_:    # if hextet is not '', directly append
+        #         adlt.append(hex_)
+        #         last = False
+        #     else:       # if hextet is '', append '0'
+        #         adlt.append('0')
+        #         if last:    # if last hextet is '', ascend counter
+        #             ctr_[ptr_] += 1
+        #         else:       # if last hextet is not '', record pointer
+        #             ptr_ = _
+        #             last = True
+        #             ctr_[ptr_] = 1
 
-        ptr_ = max(ctr_, key=ctr_.get) if ctr_ else 0   # fetch start pointer with longest zero values
-        end_ = ptr_ + ctr_[ptr_]                        # calculate end pointer
+        # ptr_ = max(ctr_, key=ctr_.get) if ctr_ else 0   # fetch start pointer with longest zero values
+        # end_ = ptr_ + ctr_[ptr_]                        # calculate end pointer
 
-        if ctr_[ptr_] > 1:      # only ommit if zero values are in a consecutive group
-            del adlt[ptr_:end_] # remove zero values
+        # if ctr_[ptr_] > 1:      # only ommit if zero values are in a consecutive group
+        #     del adlt[ptr_:end_] # remove zero values
 
-            if ptr_ == 0 and end_ == 8:     # insert `::` if IPv6 unspecified address (::)
-                adlt.insert(ptr_, '::')
-            elif ptr_ == 0 or end_ == 8:    # insert `:` if zero values are from start or at end
-                adlt.insert(ptr_, ':')
-            else:                           # insert '' otherwise
-                adlt.insert(ptr_, '')
+        #     if ptr_ == 0 and end_ == 8:     # insert `::` if IPv6 unspecified address (::)
+        #         adlt.insert(ptr_, '::')
+        #     elif ptr_ == 0 or end_ == 8:    # insert `:` if zero values are from start or at end
+        #         adlt.insert(ptr_, ':')
+        #     else:                           # insert '' otherwise
+        #         adlt.insert(ptr_, '')
 
-        addr = ':'.join(adlt)
-        return addr
+        # addr = ':'.join(adlt)
+        # return addr
+        return ipaddress.ip_address(self._read_fileng(16))
 
     def _decode_next_layer(self, ipv6, proto=None, length=None):
         """Decode next layer extractor.
 
-        Keyword arguments:
-            ipv6 -- dict, info buffer
-            proto -- str, next layer protocol name
-            length -- int, valid (not padding) length
+        Positional arguments:
+            * ipv6 -- dict, info buffer
+            * proto -- str, next layer protocol name
+            * length -- int, valid (not padding) length
+
+        Returns:
+            * dict -- current protocol with next layer extracted
 
         """
         # recurse if next header is an extensive header
