@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 """destination options for IPv6
 
-``jspcap.protocols.internet.ipv6_opts`` contains
-``IPv6_Opts`` only, which implements extractor for
+`jspcap.protocols.internet.ipv6_opts` contains
+`IPv6_Opts` only, which implements extractor for
 Destination Options for IPv6 (IPv6-Opts), whose structure
 is described as below.
 
@@ -18,13 +18,7 @@ is described as below.
 
 """
 # TODO: Implements extractor of all destination options.
-
-
-# Destination Options for IPv6
-# Analyser for IPv6-Opts header
-
-
-from jspcap.utilities import Info
+from jspcap.corekit.infoclass import Info
 from jspcap.protocols.protocol import Protocol
 
 
@@ -103,10 +97,10 @@ class IPv6_Opts(Protocol):
             |                                                               |
             +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 
-            Octets          Bits          Name                Discription
-              0              0          opt.next          Next Header
-              1              8          opt.length        Header Extensive Length
-              2              16         opt.options       Options
+            Octets      Bits        Name                    Discription
+              0           0     opt.next                Next Header
+              1           8     opt.length              Header Extensive Length
+              2          16     opt.options             Options
 
         """
         if length is None:
