@@ -1,24 +1,19 @@
 # -*- coding: utf-8 -*-
 """ethernet protocol
 
-``jspcap.protocols.link.ethernet`` contains ``Ethernet``
+`jspcap.protocols.link.ethernet` contains `Ethernet`
 only, which implements extractor for Ethernet Protocol,
 whose structure is described as below.
 
-    Octets          Bits          Name                Discription
-      0              0          eth.dst           Destination MAC Address
-      1              8          eth.src           Source MAC Address
-      2              16         eth.type          Protocol (Internet Layer)
+Octets      Bits        Name                    Discription
+  0           0     eth.dst                 Destination MAC Address
+  1           8     eth.src                 Source MAC Address
+  2          16     eth.type                Protocol (Internet Layer)
 
 """
 import textwrap
 
-
-# Ethernet Protocol
-# Analyser for ethernet protocol header
-
-
-from jspcap.utilities import Info
+from jspcap.corekit.infoclass import Info
 from jspcap.protocols.link.link import Link
 
 
@@ -29,9 +24,9 @@ class Ethernet(Link):
     """This class implements Ethernet Protocol.
 
     Properties:
-        * name -- str, name of corresponding procotol
+        * name -- str, name of corresponding protocol
         * info -- Info, info dict of current instance
-        * alias -- str, acronym of corresponding procotol
+        * alias -- str, acronym of corresponding protocol
         * layer -- str, `Link`
         * length -- int, header length of corresponding protocol
         * protocol -- str, next layer protocol
@@ -39,6 +34,9 @@ class Ethernet(Link):
         * src -- str, source mac address
         * dst -- str, destination mac address
 
+    Methods:
+        * read_ethernet -- read Ethernet Protocol
+
     Attributes:
         * _file -- BytesIO, bytes to be extracted
         * _info -- Info, info dict of current instance
@@ -94,10 +92,10 @@ class Ethernet(Link):
         """Read Ethernet Protocol.
 
         Structure of Ethernet Protocol header [RFC 7042]:
-            Octets          Bits          Name                Discription
-              0              0          eth.dst           Destination MAC Address
-              1              8          eth.src           Source MAC Address
-              2              16         eth.type          Protocol (Internet Layer)
+            Octets      Bits        Name                    Discription
+              0           0     eth.dst                 Destination MAC Address
+              1           8     eth.src                 Source MAC Address
+              2          16     eth.type                Protocol (Internet Layer)
 
         """
         if length is None:
