@@ -1,47 +1,22 @@
 # -*- coding: utf-8 -*-
 """root link layer protocol
 
-``jspcap.protocols.link.link`` contains both ``LINKTYPE``
-and ``Link``. The former is a dictionary of link layer header
+`jspcap.protocols.link.link` contains both `LINKTYPE`
+and `Link`. The former is a dictionary of link layer header
 type values, registered in IANA. And the latter is a base
 class for link layer protocols, eg. ARP/InARP, Ethernet,
 L2TP, OSPF, RARP/DRARP and etc.
 
 """
-# TODO: Implements DSL, EAPOL, FDDI, ISDN, NDP, PPP.
-
-
 import io
 
-
-# Link Layer Protocols
-# Table of corresponding protocols
-
-
-from jspcap.utilities import beholder
-from jspcap.protocols.protocol import Protocol
 from jspcap.protocols.internet.internet import ETHERTYPE
+from jspcap.protocols.protocol import Protocol
 
 
 __all__ = ['Link', 'LINKTYPE']
 
 
-# ##############################################################################
-# # for unknown reason and never-encountered situation, at current time
-# # we have to change the working directory to import from parent folders
-#
-# import os
-# import sys
-# sys.path.insert(1, os.path.join(sys.path[0], '..'))
-#
-# from protocol import Protocol
-#
-# del sys.path[1]
-#
-# # and afterwards, we recover the whole scene back to its original state
-# ##############################################################################
-
-
 # Link-Layer Header Type Values
 LINKTYPE = {
     0 : 'Null',     # BSD loopback encapsulation
@@ -57,9 +32,9 @@ class Link(Protocol):
     """Abstract base class for link layer protocol family.
 
     Properties:
-        * name -- str, name of corresponding procotol
+        * name -- str, name of corresponding protocol
         * info -- Info, info dict of current instance
-        * alias -- str, acronym of corresponding procotol
+        * alias -- str, acronym of corresponding protocol
         * layer -- str, `Link`
         * length -- int, header length of corresponding protocol
         * protocol -- str, name of next layer protocol
@@ -99,21 +74,29 @@ class Link(Protocol):
     def _read_protos(self, size):
         """Read next layer protocol type.
 
-        Keyword arguments:
-            size  -- int, buffer size
+        Positional arguments:
+            * size  -- int, buffer size
+
+        Returns:
+            * str -- next layer's protocol name
 
         """
         _byte = self._read_unpack(size)
         _prot = ETHERTYPE.get(_byte)
         return _prot
 
-    @beholder
     def _import_next_layer(self, proto, length):
         """Import next layer extractor.
 
-        Keyword arguments:
-            proto -- str, next layer protocol name
-            length -- int, valid (not padding) length
+        Positional arguments:
+            * proto -- str, next layer protocol name
+            * length -- int, valid (not padding) length
+
+        Returns:
+            * bool -- flag if extraction of next layer succeeded
+            * Info -- info of next layer
+            * ProtoChain -- protocol chain of next layer
+            * str -- alias of next layer
 
         Protocols:
             * ARP -- data link layer
@@ -124,7 +107,9 @@ class Link(Protocol):
             * IPX -- internet layer
 
         """
-        if proto == 'ARP':
+        if self._sigterm:
+            from jspcap.protocols.raw import Raw as Protocol
+        elif proto == 'ARP':
             from jspcap.protocols.link.arp import ARP as Protocol
         elif proto == 'RARP':
             from jspcap.protocols.link.rarp import RARP as Protocol
@@ -138,5 +123,6 @@ class Link(Protocol):
             from jspcap.protocols.internet.ipx import IPX as Protocol
         else:
             from jspcap.protocols.raw import Raw as Protocol
-        next_ = Protocol(io.BytesIO(self._read_fileng(length)), length)
+        next_ = Protocol(io.BytesIO(self._read_fileng(length)), length,
+                            error=self._onerror, layer=self._exlayer, protocol=self._exproto)
         return True, next_.info, next_.protochain, next_.alias
