@@ -1,27 +1,23 @@
 # -*- coding: utf-8 -*-
 """(dynamic) reverse address resolution protocol
 
-``jspcap.protocols.link.rarp`` contains ``RARP`` only,
+`jspcap.protocols.link.rarp` contains `RARP` only,
 which implements extractor for (Dynamic) Reverse Address
 Resolution Protocol (RARP/DRARP), whose structure is
 described as below.
 
-    Octets          Bits          Name                Discription
-      0              0          rarp.htype        Hardware Type
-      2              16         rarp.ptype        Protocol Type
-      4              32         rarp.hlen         Hardware Address Length
-      5              40         rarp.plen         Protocol Address Length
-      6              48         rarp.oper         Operation
-      8              64         rarp.sha          Sender Hardware Address
-      14             112        rarp.spa          Sender Protocol Address
-      18             144        rarp.tha          Target Hardware Address
-      24             192        rarp.tpa          Target Protocol Address
+Octets      Bits        Name                    Discription
+  0           0     rarp.htype              Hardware Type
+  2          16     rarp.ptype              Protocol Type
+  4          32     rarp.hlen               Hardware Address Length
+  5          40     rarp.plen               Protocol Address Length
+  6          48     rarp.oper               Operation
+  8          64     rarp.sha                Sender Hardware Address
+  14        112     rarp.spa                Sender Protocol Address
+  18        144     rarp.tha                Target Hardware Address
+  24        192     rarp.tpa                Target Protocol Address
 
 """
-# Reverse Address Resolution Protocol
-# Analyser for RARP/DRARP header
-
-
 from jspcap.protocols.link.arp import ARP
 
 
@@ -32,9 +28,9 @@ class RARP(ARP):
     """This class implements Reverse Address Resolution Protocol.
 
     Properties:
-        * name -- str, name of corresponding procotol
+        * name -- str, name of corresponding protocol
         * info -- Info, info dict of current instance
-        * alias -- str, acronym of corresponding procotol
+        * alias -- str, acronym of corresponding protocol
         * layer -- str, `Link`
         * length -- int, header length of corresponding protocol
         * protochain -- ProtoChain, protocol chain of current instance
@@ -49,8 +45,8 @@ class RARP(ARP):
         * _file -- BytesIO, bytes to be extracted
         * _info -- Info, info dict of current instance
         * _protos -- ProtoChain, protocol chain of current instance
-        * _acnm -- str, acronym of corresponding procotol
-        * _name -- str, name of corresponding procotol
+        * _acnm -- str, acronym of corresponding protocol
+        * _name -- str, name of corresponding protocol
 
     Utilities:
         * _read_protos -- read next layer protocol type
@@ -73,4 +69,4 @@ class RARP(ARP):
 
     @classmethod
     def __index__(cls):
-        return ('RARP', 'DRARPD')
+        return ('RARP', 'DRARP')
