@@ -1,25 +1,19 @@
 # -*- coding: utf-8 -*-
 """802.1Q customer VLAN tag type
 
-``jspcap.protocols.link.vlan`` contains ``VLAN``
+`jspcap.protocols.link.vlan` contains `VLAN`
 only, which implements extractor for 802.1QCustomer
 VLAN Tag Type, whose structure is described as below.
 
-    Octets          Bits          Name                Discription
-      1              0         vlan.tci          Tag Control Information
-      1              0         vlan.tci.pcp      Priority Code Point
-      1              3         vlan.tci.dei      Drop Eligible Indicator
-      1              4         vlan.tci.vid      VLAN Identifier
-      3              24        vlan.type         Protocol (Internet Layer)
+Octets      Bits        Name                    Discription
+  1           0     vlan.tci                Tag Control Information
+  1           0     vlan.tci.pcp            Priority Code Point
+  1           3     vlan.tci.dei            Drop Eligible Indicator
+  1           4     vlan.tci.vid            VLAN Identifier
+  3          24     vlan.type               Protocol (Internet Layer)
 
 """
-
-
-# 802.1Q Customer VLAN Tag Type
-# Analyser for 802.1Q customer VLAN tag type
-
-
-from jspcap.utilities import Info
+from jspcap.corekit.infoclass import Info
 from jspcap.protocols.link.link import Link
 
 __all__ = ['VLAN']
@@ -42,14 +36,17 @@ class VLAN(Link):
     """This class implements 802.1Q Customer VLAN Tag Type.
 
     Properties:
-        * name -- str, name of corresponding procotol
+        * name -- str, name of corresponding protocol
         * info -- Info, info dict of current instance
-        * alias -- str, acronym of corresponding procotol
+        * alias -- str, acronym of corresponding protocol
         * layer -- str, `Link`
         * length -- int, header length of corresponding protocol
         * protocol -- str, next layer protocol
         * protochain -- ProtoChain, protocol chain of current instance
 
+    Methods:
+        * read_vlan -- read 802.1Q Customer VLAN Tag Type
+
     Attributes:
         * _file -- BytesIO, bytes to be extracted
         * _info -- Info, info dict of current instance
@@ -76,7 +73,7 @@ class VLAN(Link):
 
     @property
     def alias(self):
-        """Acronym of corresponding procotol."""
+        """Acronym of corresponding protocol."""
         return '802.1Q'
 
     @property
@@ -93,16 +90,16 @@ class VLAN(Link):
     # Methods.
     ##########################################################################
 
-    def read_ctag(self, length):
+    def read_vlan(self, length):
         """Read 802.1Q Customer VLAN Tag Type.
 
         Structure of 802.1Q Customer VLAN Tag Type [RFC 7042]:
-            Octets          Bits          Name                Discription
-              1              0         vlan.tci          Tag Control Information
-              1              0         vlan.tci.pcp      Priority Code Point
-              1              3         vlan.tci.dei      Drop Eligible Indicator
-              1              4         vlan.tci.vid      VLAN Identifier
-              3              24        vlan.type         Protocol (Internet Layer)
+            Octets      Bits        Name                    Discription
+              1           0     vlan.tci                Tag Control Information
+              1           0     vlan.tci.pcp            Priority Code Point
+              1           3     vlan.tci.dei            Drop Eligible Indicator
+              1           4     vlan.tci.vid            VLAN Identifier
+              3          24     vlan.type               Protocol (Internet Layer)
 
         """
         if length is None:
@@ -131,7 +128,7 @@ class VLAN(Link):
 
     def __init__(self, _file, length=None, **kwargs):
         self._file = _file
-        self._info = Info(self.read_ctag(length))
+        self._info = Info(self.read_vlan(length))
 
     def __length_hint__(self):
         return 4
