@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """root protocol
 
-``jspcap.protocols.protocol`` contains ``Protocol`` only,
+`jspcap.protocols.protocol` contains `Protocol` only,
 which is an abstract base clss for all protocol family,
 with pre-defined utility arguments and methods of specified
 protocols.
@@ -12,23 +12,25 @@ import copy
 import io
 import numbers
 import os
+import re
 import struct
 import textwrap
 
+from jspcap.corekit.infoclass import Info
+from jspcap.corekit.protochain import ProtoChain
+from jspcap.utilities.decorators import beholder, seekset
+from jspcap.utilities.exceptions import BoolError, BytesError, StructError
+from jspcap.utilities.validations import bool_check, int_check
 
-# Abstract Base Class of Protocols
-# Pre-define useful arguments and methods of protocols
-
-
-from jspcap.exceptions import BoolError, BytesError, StructError
-from jspcap.utilities import seekset, Info, ProtoChain
-from jspcap.validations import bool_check, int_check
+###############################################################################
 # from jspcap.protocols.raw import Raw
+###############################################################################
 
 
 __all__ = ['Protocol']
 
 
+# abstract base class utilities
 ABCMeta = abc.ABCMeta
 abstractmethod = abc.abstractmethod
 abstractproperty = abc.abstractproperty
@@ -38,9 +40,9 @@ class Protocol:
     """Abstract base class for all protocol family.
 
     Properties:
-        * name -- str, name of corresponding procotol
+        * name -- str, name of corresponding protocol
         * info -- Info, info dict of current instance
-        * alias -- str, acronym of corresponding procotol
+        * alias -- str, acronym of corresponding protocol
         * length -- int, header length of corresponding protocol
         * protocol -- str, name of next layer protocol
         * protochain -- ProtoChain, protocol chain of current instance
@@ -60,6 +62,7 @@ class Protocol:
         * _import_next_layer -- import next layer protocol extractor
 
     """
+    __layer__ = None
     __metaclass__ = ABCMeta
 
     ##########################################################################
@@ -114,6 +117,10 @@ class Protocol:
 
     def __new__(cls, *args, **kwargs):
         self = super().__new__(cls)
+        self._onerror = kwargs.pop('error', False)
+        self._exlayer = kwargs.pop('layer', str())
+        self._exproto = kwargs.pop('protocol', str())
+        self._sigterm = self._check_termination()
         return self
 
     def __repr__(self):
@@ -141,9 +148,9 @@ class Protocol:
         pass
 
     def __iter__(self):
-        file_ = copy.deepcopy(self._file)
-        file_.seek(os.SEEK_SET)
-        return iter(file_)
+        file = copy.deepcopy(self._file)
+        file.seek(os.SEEK_SET)
+        return iter(file)
 
     # def __next__(self):
     #     next_ = self._file.read(1)
@@ -167,8 +174,12 @@ class Protocol:
     def _read_protos(self, size):
         """Read next layer protocol type.
 
-        Keyword arguments:
-            size  -- int, buffer size
+        Positional arguments:
+            * size  -- int, buffer size
+
+        Returns:
+            * [upon success] str -- name of next layer protocol
+            * [upon failure] None
 
         """
         return None
@@ -180,22 +191,27 @@ class Protocol:
     def _read_unpack(self, size=1, *, signed=False, lilendian=False, quiet=False):
         """Read bytes and unpack for integers.
 
+        Positional arguments:
+            * size  -- int, buffer size (default is 1)
+
         Keyword arguments:
-            size       -- int, buffer size (default is 1)
-            signed     -- bool, signed flag (default is False)
+            * signed -- bool, signed flag (default is False)
                            <keyword> True / False
-            lilendian  -- bool, little-endian flag (default is False)
+            * lilendian -- bool, little-endian flag (default is False)
                            <keyword> True / False
-            quiet      -- bool, quiet (no exception) flag (default is False)
+            * quiet -- bool, quiet (no exception) flag (default is False)
                            <keyword> True / False
 
+        Returns:
+            * int -- unpacked data upon success
+
         """
         endian = '<' if lilendian else '>'
-        if size == 8:   kind = 'q' if signed else 'Q' # unpack to 8-byte integer (long long)
-        elif size == 4: kind = 'i' if signed else 'I' # unpack to 4-byte integer (int / long)
-        elif size == 2: kind = 'h' if signed else 'H' # unpack to 2-byte integer (short)
-        elif size == 1: kind = 'b' if signed else 'B' # unpack to 1-byte integer (char)
-        else:           kind = None                 # do not unpack
+        if size == 8:   kind = 'q' if signed else 'Q'   # unpack to 8-byte integer (long long)
+        elif size == 4: kind = 'i' if signed else 'I'   # unpack to 4-byte integer (int / long)
+        elif size == 2: kind = 'h' if signed else 'H'   # unpack to 2-byte integer (short)
+        elif size == 1: kind = 'b' if signed else 'B'   # unpack to 1-byte integer (char)
+        else:           kind = None                     # do not unpack
 
         if kind is None:
             mem = self._file.read(size)
@@ -216,8 +232,11 @@ class Protocol:
     def _read_binary(self, size=1):
         """Read bytes and convert into binaries.
 
-        Keyword arguments:
-            size  -- int, buffer size (default is 1)
+        Positional arguments:
+            * size  -- int, buffer size (default is 1)
+
+        Returns:
+            * str -- binary bits (0/1)
 
         """
         bin_ = ''
@@ -229,12 +248,21 @@ class Protocol:
     @seekset
     def _read_packet(self, length=None, *, header=None, payload=None, discard=False):
         """Read raw packet data.
-        
+
+        Positional arguments:
+            * length -- int, length of the packet
+
         Keyword arguments:
-            length -- int, length of the packet
-            header -- int, length of the packet header
-            payload -- int, length of the packet payload
-            discard -- bool, flag if discard header data
+            * header -- int, length of the packet header
+            * payload -- int, length of the packet payload
+            * discard -- bool, flag if discard header data (False in default)
+
+        Returns:
+            * [if header omits] bytes -- whole packet data
+            * [if discard set True] bytes -- packet body only
+            * dict -- header and payload data
+                |-- 'header' -- bytes, packet header
+                |-- 'payload' -- bytes, packet payload
 
         """
         if header is not None:
@@ -248,13 +276,19 @@ class Protocol:
     def _decode_next_layer(self, dict_, proto=None, length=None):
         """Decode next layer protocol.
 
-        Keyword arguments:
-            dict_ -- dict, info buffer
-            proto -- str, next layer protocol name
-            length -- int, valid (not padding) length
+        Positional arguments:
+            * dict_ -- dict, info buffer
+            * proto -- str, next layer protocol name
+            * length -- int, valid (not padding) length
+
+        Returns:
+            * dict -- current protocol with next layer extracted
 
         """
-        flag, info, chain, alias = self._import_next_layer(proto, length)
+        if self._onerror:
+            flag, info, chain, alias = beholder(self._import_next_layer)(self, proto, length)
+        else:
+            flag, info, chain, alias = self._import_next_layer(proto, length)
 
         # make next layer protocol name
         if flag:
@@ -274,11 +308,25 @@ class Protocol:
     def _import_next_layer(self, proto, length=None):
         """Import next layer extractor.
 
-        Keyword arguments:
-            proto -- str, next layer protocol name
-            length -- int, valid (not padding) length
+        Positional arguments:
+            * proto -- str, next layer protocol name
+            * length -- int, valid (not padding) length
+
+        Returns:
+            * bool -- flag if extraction of next layer succeeded
+            * Info -- info of next layer
+            * ProtoChain -- protocol chain of next layer
+            * str -- alias of next layer
 
         """
         from jspcap.protocols.raw import Raw
-        next_ = Raw(io.BytesIO(self._read_fileng(length)), length)
+        next_ = Raw(io.BytesIO(self._read_fileng(length)), length,
+                    layer=self._exlayer, protocol=self._exproto)
         return True, next_.info, next_.protochain, next_.alias
+
+    def _check_termination(self):
+        index = self.__index__()
+        pattern = '|'.join(index) if isinstance(index, tuple) else index
+        iterable = self._exproto if isinstance(self._exproto, tuple) else (self._exproto,)
+        match = filter(lambda string: re.fullmatch(pattern, string, re.IGNORECASE), iterable)
+        return bool(len(list(match)) or re.fullmatch(self.__layer__ or '', self._exlayer, re.IGNORECASE))
