@@ -1,11 +1,13 @@
 # -*- coding: utf-8 -*-
 """transport layer protocols
 
-``jspcap.protocols.transport`` is collection of all
-protocols in transport layer, with detailed implementation
-and methods.
+`jspcap.protocols.transport` is collection of all protocols
+in transport layer, with detailed implementation and
+methods.
 
 """
+# TODO: Implements DCCP, RSVP, STCP.
+
 # Base Class for Transport Layer
 from jspcap.protocols.transport.transport import Transport
 
