@@ -1,47 +1,26 @@
 # -*- coding: utf-8 -*-
 """root transport layer protocol
 
-``jspcap.protocols.transport.transport`` contains both
-``TP_PROTO`` and ``Transport``. The former is a dictionary
+`jspcap.protocols.transport.transport` contains both
+`TP_PROTO` and `Transport`. The former is a dictionary
 of transport layer protocol numbers, registered in IANA.
 And the latter is a base class for transport layer
 protocols, eg. TCP and UDP.
 
 """
-# TODO: Implements DCCP, RSVP, STCP.
-
-
 import io
 
-
-# Transport Layer Protocols
-# Table of corresponding protocols
-
-
-from jspcap.analyser import analyse
-from jspcap.utilities import beholder
 from jspcap.protocols.protocol import Protocol
+from jspcap.utilities.decorators import beholder_ng
+
+###############################################################################
+# from jspcap.fundation.analysis import analyse
+###############################################################################
 
 
 __all__ = ['Transport', 'TP_PROTO']
 
 
-# ##############################################################################
-# # for unknown reason and never-encountered situation, at current time
-# # we have to change the working directory to import from parent folders
-#
-# import os
-# import sys
-# sys.path.insert(1, os.path.join(sys.path[0], '..'))
-#
-# from protocol import Protocol
-#
-# del sys.path[1]
-#
-# # and afterwards, we recover the whole scene back to its original state
-# ##############################################################################
-
-
 # Transport Layer Protocol Numbers
 TP_PROTO = {
     # Internet Layer
@@ -113,14 +92,23 @@ class Transport(Protocol):
     # Utilities.
     ##########################################################################
 
-    @beholder
     def _import_next_layer(self, proto, length):
         """Import next layer extractor.
 
-        Keyword arguments:
-            proto -- str, next layer protocol name
-            length -- int, valid (not padding) length
+        Positional arguments:
+            * proto -- str, next layer protocol name
+            * length -- int, valid (not padding) length
+
+        Returns:
+            * bool -- flag if extraction of next layer succeeded
+            * Info -- info of next layer
+            * ProtoChain -- protocol chain of next layer
+            * str -- alias of next layer
 
         """
-        next_ = analyse(io.BytesIO(self._read_fileng(length)), length)
+        from jspcap.foundation.analysis import Analysis
+        if self._onerror:
+            next_ = beholder_ng(Analysis.analyse)(io.BytesIO(self._read_fileng(length)), length, _termination=self._sigterm)
+        else:
+            next_ = Analysis.analyse(io.BytesIO(self._read_fileng(length)), length, _termination=self._sigterm)
         return True, next_.info, next_.protochain, next_.alias
