@@ -1,67 +1,79 @@
 # -*- coding: utf-8 -*-
 """reassembly TCP datagram
 
-``jspcap.reassembly.tcp`` contains ``TCP_Reassembly`` only,
+`jspcap.reassembly.tcp` contains `TCP_Reassembly` only,
 which reconstructs fragmented TCP packets back to origin.
 The algorithm for TCP reassembly is decribed as below.
 
-    FO    - Fragment Offset
-    IHL   - Internet Header Length
-    MF    - More Fragments flag
-    TTL   - Time To Live
-    NFB   - Number of Fragment Blocks
-    TL    - Total Length
-    TDL   - Total Data Length
-    BUFID - Buffer Identifier
-    RCVBT - Fragment Received Bit Table
-    TLB   - Timer Lower Bound
+Notations:
 
-DO {
-    BUFID <- source|destination|protocol|identification;
+    DSN     - Data Sequence Number 
+    ACK     - TCP Acknowledgement
+    FIN     - TCP Finish Flag
+    SYN     - TCP Synchronisation Flag
+    BUFID   - Buffer Identifier
+    HDL     - Hole Discriptor List
+    ISN     - Initial Sequence Number
+    src     - source IP
+    dst     - destionation IP
+    srcport - source TCP port
+    dstport - destionation TCP port
 
-    IF (FO = 0 AND MF = 0) {
-        IF (buffer with BUFID is allocated) {
-            flush all reassembly for this BUFID;
-            Submit datagram to next step;
-            DONE.
+Algorithm:
+
+    DO { 
+        BUFID <- src|dst|srcport|dstport|ACK;  
+        IF (SYN is true) { 
+            IF (buffer with BUFID is allocated) { 
+                flush all reassembly for this BUFID; 
+                submit datagram to next step; 
+            } 
+        }  
+
+        IF (no buffer with BUFID is allocated) { 
+            allocate reassembly resources with BUFID; 
+            ISN <- DSN; 
+            put data from fragment into data buffer with BUFID
+                [from octet fragment.first to octet fragment.last]; 
+            update HDL; 
+        }  
+
+        IF (FIN is true) { 
+            submit datagram to next step; 
+            free all reassembly resources for this BUFID; 
+            BREAK. 
         }
-    }
+      } give up until (next fragment);
 
-    IF (no buffer with BUFID is allocated) {
-        allocate reassembly resources with BUFID;
-        TIMER <- TLB;
-        TDL <- 0;
-        put data from fragment into data buffer with BUFID
-            [from octet FO*8 to octet (TL-(IHL*4))+FO*8];
-        set RCVBT bits [from FO to FO+((TL-(IHL*4)+7)/8)];
-    }
+    update HDL: { 
+        DO { 
+            select the next hole descriptor from HDL;  
 
-    IF (MF = 0) {
-        TDL <- TL-(IHL*4)+(FO*8)
-    }
+            IF (fragment.first >= hole.first) CONTINUE. 
+            IF (fragment.last <= hole.first) CONTINUE.  
 
-    IF (FO = 0) {
-        put header in header buffer
-    }
+            delete the current entry from HDL;  
 
-    IF (TDL # 0 AND all RCVBT bits [from 0 to (TDL+7)/8] are set) {
-        TL <- TDL+(IHL*4)
-        Submit datagram to next step;
-        free all reassembly resources for this BUFID;
-        DONE.
-    }
+            IF (fragment.first >= hole.first) { 
+                create new entry "new_hole" in HDL; 
+                new_hole.first <- hole.first; 
+                new_hole.last <- fragment.first - 1; 
+                BREAK. 
+            }  
 
-    TIMER <- MAX(TIMER,TTL);
+            IF (fragment.last <= hole.last) { 
+                create new entry "new_hole" in HDL; 
+                new_hole.first <- fragment.last + 1 ;
+                new_hole.last <- hole.last; 
+                BREAK. 
+            }
+        } give up until (no entry from HDL)
+     }
 
-} give up until (next fragment or timer expires);
-
-timer expires: {
-    flush all reassembly with this BUFID;
-    DONE.
-}
-
-And as for ``RCVBT``, there is an alternative algorithm
-described below.
+The following algorithm implementment is based on `IP Datagram
+Reassembly Algorithm` introduced in RFC 815. It descripted an
+algorithm dealing with `RCVBT` (fragment received bit table)
+appeared in RFC 791. And here is the process:
 
 1. Select the next hole descriptor from the hole descriptor
   list. If there are no more entries, go to step eight.
@@ -70,10 +82,10 @@ described below.
 4. Delete the current entry from the hole descriptor list.
 5. If fragment.first is greater than hole.first, then create a
   new hole descriptor "new_hole" with new_hole.first equal to
-  hole.first, and new_hole.last equal to fragment.first  minus
+  hole.first, and new_hole.last equal to fragment.first minus
   one.
-6. If fragment.last is less than hole.last and fragment.more
-  fragments is true, then create a new hole descriptor
+6. If fragment.last is less than hole.last and
+  fragment.more_fragments is true, then create a new hole descriptor
   "new_hole", with new_hole.first equal to fragment.last plus
   one and new_hole.last equal to hole.last.
 7. Go to step one.
@@ -86,13 +98,8 @@ import copy
 import io
 import sys
 
-
-# Reassembly TCP Datagram
-# Reconstruct application layer packets
-
-
-from jspcap.analyser import analyse
-from jspcap.utilities import Info
+from jspcap.corekit.infoclass import Info
+from jspcap.foundation.analysis import Analysis
 from jspcap.reassembly.reassembly import Reassembly
 
 
@@ -103,7 +110,7 @@ class TCP_Reassembly(Reassembly):
     """Reassembly for TCP payload.
 
     Usage:
-        >>> from reassembly import TCP_Reassembly
+        >>> from jspcap.reassembly import TCP_Reassembly
         # Initialise instance:
         >>> tcp_reassembly = TCP_Reassembly()
         # Call reassembly:
@@ -111,16 +118,12 @@ class TCP_Reassembly(Reassembly):
         # Fetch result:
         >>> result = tcp_reassembly.datagram
 
-    Keyword arguments:
-        * strict -- bool, if strict set to True, all datagram will return
-                    else only implemented ones will submit (False in default)
-                    < True / False >
-
     Properties:
         * name -- str, protocol of current packet
         * count -- int, total number of reassembled packets
         * datagram -- tuple, reassembled datagram, which structure may vary
                         according to its protocol
+        * protocol -- str, protocol of current reassembly object
 
     Methods:
         * reassembly -- perform the reassembly procedure
@@ -134,29 +137,6 @@ class TCP_Reassembly(Reassembly):
         * _buffer -- dict, buffer field
         * _dtgram -- tuple, reassembled datagram
 
-    The following algorithm implementment is based on `IP Datagram
-    Reassembly Algorithm` introduced in RFC 815. It descripted an
-    algorithm dealing with `RCVBT` (fragment received bit table)
-    appeared in RFC 791. And here is the process:
-
-    1. Select the next hole descriptor from the hole descriptor
-      list. If there are no more entries, go to step eight.
-    2. If fragment.first is greater than hole.last, go to step one.
-    3. If fragment.last is less than hole.first, go to step one.
-    4. Delete the current entry from the hole descriptor list.
-    5. If fragment.first is greater than hole.first, then create a
-      new hole descriptor "new_hole" with new_hole.first equal to
-      hole.first, and new_hole.last equal to fragment.first  minus
-      one.
-    6. If fragment.last is less than hole.last and fragment.more
-      fragments is true, then create a new hole descriptor
-      "new_hole", with new_hole.first equal to fragment.last plus
-      one and new_hole.last equal to hole.last.
-    7. Go to step one.
-    8. If the hole descriptor list is now empty, the datagram is now
-      complete. Pass it on to the higher level protocol processor
-      for further handling. Otherwise, return.
-
     Terminology:
         - packet_dict = Info(
             bufid = tuple(
@@ -174,7 +154,7 @@ class TCP_Reassembly(Reassembly):
             first = tcp.seq,                # this sequence number
             last = tcp.seq + tcp.raw_len,   # next (wanted) sequence number
             payload = tcp.raw,              # raw bytearray type payload
-        )
+         )
         - (tuple) datagram
            |--> (Info) data
            |       |--> 'NotImplemented' : (bool) True --> implemented
@@ -189,6 +169,7 @@ class TCP_Reassembly(Reassembly):
            |       |--> 'index' : (tuple) packet numbers
            |       |                |--> (int) original packet range number
            |       |--> 'payload' : (bytes/None) reassembled application layer data
+           |       |--> 'packets' : (tuple<Analysis>) analysed payload
            |--> (Info) data
            |       |--> 'NotImplemented' : (bool) False --> not implemented
            |       |--> 'id' : (Info) original packet identifier
@@ -203,7 +184,8 @@ class TCP_Reassembly(Reassembly):
            |       |--> 'index' : (tuple) packet numbers
            |       |                |--> (int) original packet range number
            |       |--> 'payload' : (tuple/None) partially reassembled payload
-           |                        |--> (bytes/None) payload fragment
+           |       |                |--> (bytes/None) payload fragment
+           |       |--> 'packets' : (tuple<Analysis>) analysed payloads
            |--> (Info) data ...
         - (dict) buffer --> memory buffer for reassembly
            |--> (tuple) BUFID : (dict)
@@ -236,6 +218,11 @@ class TCP_Reassembly(Reassembly):
         """Protocol of current packet."""
         return 'Transmission Control Protocol'
 
+    @property
+    def protocol(self):
+        """Protocol of current reassembly object."""
+        return 'TCP'
+
     ##########################################################################
     # Methods.
     ##########################################################################
@@ -243,8 +230,8 @@ class TCP_Reassembly(Reassembly):
     def reassembly(self, info):
         """Reassembly procedure.
 
-        Keyword arguments:
-            * info - Info, info dict of packets to be reassembled
+        Positional arguments:
+            * info -- Info, info dict of packets to be reassembled
 
         """
         BUFID = info.bufid  # Buffer Identifier
@@ -254,8 +241,12 @@ class TCP_Reassembly(Reassembly):
         SYN = info.syn      # Synchronise Flag (Establishment)
 
         # when SYN is set, reset buffer of this session
-        # initialise buffer with BUFID & ACK then recurse
-        if SYN or BUFID not in self._buffer:
+        if SYN and BUFID in self._buffer:
+            self._dtgram += self.submit(self._buffer[BUFID], bufid=BUFID)
+            del self._buffer[BUFID]
+
+        # initialise buffer with BUFID & ACK
+        if BUFID not in self._buffer:
             self._buffer[BUFID] = {
                 'hdl' : [Info(first=info.len, last=sys.maxsize),],
                 ACK : dict(
@@ -330,10 +321,15 @@ class TCP_Reassembly(Reassembly):
     def submit(self, buf, *, bufid):
         """Submit reassembled payload.
 
-        Keyword arguments:
+        Positional arguments:
             * buf -- dict, buffer dict of reassembled packets
+
+        Keyword arguments:
             * bufid -- tuple, buffer identifier
 
+        Returns:
+            * list -- reassembled packets
+
         """
         datagram = []           # reassembled datagram
         HDL = buf.pop('hdl')    # hole descriptor list (remove from dict)
@@ -364,7 +360,7 @@ class TCP_Reassembly(Reassembly):
                         ),
                         index = tuple(buffer['ind']),
                         payload = tuple(data) or None,
-                        packets = tuple([ analyse(io.BytesIO(frag), len(frag)) for frag in data ]),
+                        packets = tuple([ Analysis.analyse(io.BytesIO(frag), len(frag)) for frag in data ]),
                     )
                     datagram.append(packet)
             # if this buffer is implemented
@@ -381,7 +377,7 @@ class TCP_Reassembly(Reassembly):
                         ),
                         index = tuple(buffer['ind']),
                         payload = bytes(data) or None,
-                        packets = (analyse(io.BytesIO(data), len(data)),),
+                        packets = (Analysis.analyse(io.BytesIO(data), len(data)),),
                     )
                     datagram.append(packet)
         return datagram
